@@ -3,8 +3,6 @@
  *
  */
 
-/* $Xorg: mipointrst.h,v 1.4 2001/02/09 02:05:21 xorgcvs Exp $ */
-
 /*
 
 Copyright 1989, 1998  The Open Group
@@ -29,36 +27,30 @@ Except as contained in this notice, the name of The Open Group shall not be
 used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 */
-/* $XFree86: xc/programs/Xserver/mi/mipointrst.h,v 1.3 2001/04/19 14:14:07 tsi Exp $ */
+
+#ifndef MIPOINTRST_H
+#define MIPOINTRST_H
 
 #include "mipointer.h"
 #include "scrnintstr.h"
 
-#define MOTION_SIZE	256
-
 typedef struct {
-    xTimecoord	    event;
-    ScreenPtr	    pScreen;
-} miHistoryRec, *miHistoryPtr;
-
-typedef struct {
-    ScreenPtr		    pScreen;    /* current screen */
-    ScreenPtr		    pSpriteScreen;/* screen containing current sprite */
-    CursorPtr		    pCursor;    /* current cursor */
-    CursorPtr		    pSpriteCursor;/* cursor on screen */
-    BoxRec		    limits;	/* current constraints */
-    Bool		    confined;	/* pointer can't change screens */
-    int			    x, y;	/* hot spot location */
-    int			    devx, devy;	/* sprite position */
-    DevicePtr		    pPointer;   /* pointer device structure */
-    miHistoryRec	    history[MOTION_SIZE];
-    int			    history_start, history_end;
+    ScreenPtr pScreen;          /* current screen */
+    ScreenPtr pSpriteScreen;    /* screen containing current sprite */
+    CursorPtr pCursor;          /* current cursor */
+    CursorPtr pSpriteCursor;    /* cursor on screen */
+    BoxRec limits;              /* current constraints */
+    Bool confined;              /* pointer can't change screens */
+    int x, y;                   /* hot spot location */
+    int devx, devy;             /* sprite position */
+    Bool generateEvent;         /* generate an event during warping? */
 } miPointerRec, *miPointerPtr;
 
 typedef struct {
-    miPointerSpriteFuncPtr  spriteFuncs;	/* sprite-specific methods */
-    miPointerScreenFuncPtr  screenFuncs;	/* screen-specific methods */
-    CloseScreenProcPtr	    CloseScreen;
-    Bool		    waitForUpdate;	/* don't move cursor in SIGIO */
-    Bool		    showTransparent;	/* show empty cursors */
+    miPointerSpriteFuncPtr spriteFuncs; /* sprite-specific methods */
+    miPointerScreenFuncPtr screenFuncs; /* screen-specific methods */
+    CloseScreenProcPtr CloseScreen;
+    Bool waitForUpdate;         /* don't move cursor in SIGIO */
+    Bool showTransparent;       /* show empty cursors */
 } miPointerScreenRec, *miPointerScreenPtr;
+#endif                          /* MIPOINTRST_H */
